@@ -19,21 +19,45 @@ test_that("utils", {
   expect_true(is.fitdistcens(fluazinam_lnorm))
   expect_true(is.fitdistscens(fluazinam_dists))
   expect_true(is.fitdistcens(fluazinam_dists[[1]]))
-
+  
   expect_identical(nobs(boron_lnorm), 28L)
   expect_identical(nobs(boron_dists), nobs(boron_lnorm))
   expect_identical(nobs(fluazinam_lnorm), NA_integer_)
   expect_identical(nobs(fluazinam_dists), NA_integer_)
-
+  
   expect_identical(npars(boron_lnorm), 2L)
   expect_identical(npars(boron_dists), c(
     llogis = 2L, gamma = 2L, lnorm = 2L
   ))
   expect_identical(npars(fluazinam_lnorm), 2L)
   expect_identical(npars(fluazinam_dists), c(llogis = 2L, gamma = 2L, lnorm = 2L))
-  expect_identical(
-    comma_signif(c(0.0191, 1, NA, 1111)),
-    c("0.02", "1", NA, "1,000")
-  )
+  
   expect_equal(ssd_ecd(1:10), seq(0.05, 0.95, by = 0.1))
 })
+
+test_that("comma_signif", {
+  expect_identical(
+    comma_signif(c(0.0191, 1, NA, 177, 1111)),
+    c("0.0191", "1", NA, "177", "1,110")
+  )
+  expect_identical(
+    comma_signif(c(0.0191, 1, NA, 177, 1111), digits = 1),
+    c("0.02", "1", NA, "200", "1,000")
+  )
+  expect_identical(
+    comma_signif(c(0.1, 1)),
+    c("0.1", "1")
+  )
+  expect_identical(
+    comma_signif(c(0.1, 1, 10)),
+    c("0.1", "1", "10")
+  )
+  expect_identical(
+    comma_signif(c(0.1, 1, 10, 1000)),
+    c("0.1", "1", "10", "1,000")
+  )
+  expect_identical(
+    comma_signif(c(0.55555, 55555)),
+    c("0.556", "55,600")
+  )
+})
